FewShotLearner

Struct FewShotLearner 

pub struct FewShotLearner { /* private fields */ }
Few-shot learner for quick adaptation.

Given a small number of examples, adapts quickly using meta-learned priors.

Implementations

Source

impl FewShotLearner

pub fn from_meta(meta: &MetaLearner, task_embedding: Option<&[f32]>) -> Self

Create from meta-learner initialization.

pub fn with_adapt_lr(self, lr: f32) -> Self

Set adaptation learning rate.

pub fn with_adapt_steps(self, steps: usize) -> Self

Set number of adaptation steps.

pub fn add_example(&mut self, features: Vec<f32>, target: f32)

Add an example to the support set.

pub fn adapt(&mut self)

Adapt to the support set.

Performs gradient descent on support set to adapt parameters from meta-learned initialization.

pub fn predict(&self, features: &[f32]) -> f32

Predict for new input.

pub fn get_adapted_params(&self) -> &[f32]

Get final adapted parameters.

pub fn support_size(&self) -> usize

Number of support examples.