pub struct UpdateEntryRequest {
pub id: String,
pub title: Option<String>,
pub content: Option<String>,
pub category: Option<String>,
pub tags: Vec<String>,
pub source: Option<String>,
pub metadata: HashMap<String, String>,
}Expand description
Update entry
Fields
id: Stringtitle: Option<String>content: Option<String>category: Option<String>source: Option<String>metadata: HashMap<String, String>Implementations
Sourceimpl UpdateEntryRequest
impl UpdateEntryRequest
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn content(&self) -> &str
pub fn content(&self) -> &str
Returns the value of content, or the default value if content is unset.