pub struct RoutingRule {
pub condition: RoutingCondition,
pub knowledge_type: KnowledgeTypeHint,
}Expand description
A routing rule that maps conditions to knowledge types.
Fields
condition: RoutingConditionCondition that must match for this rule to apply.
knowledge_type: KnowledgeTypeHintThe knowledge type to assign when this rule matches.
Implementations
Sourceimpl RoutingRule
impl RoutingRule
Sourcepub fn new(
condition: RoutingCondition,
knowledge_type: KnowledgeTypeHint,
) -> Self
pub fn new( condition: RoutingCondition, knowledge_type: KnowledgeTypeHint, ) -> Self
Create a new routing rule.