pub struct ScreenshotIngester { /* private fields */ }Expand description
Screenshot ingester backed by an OCR backend implementation.
Implementations
Sourceimpl ScreenshotIngester
impl ScreenshotIngester
Sourcepub fn new(backend: Arc<dyn OcrBackend>) -> Self
pub fn new(backend: Arc<dyn OcrBackend>) -> Self
Create a new screenshot ingester with default config.
Sourcepub fn with_config(
backend: Arc<dyn OcrBackend>,
config: ScreenshotIngesterConfig,
) -> Self
pub fn with_config( backend: Arc<dyn OcrBackend>, config: ScreenshotIngesterConfig, ) -> Self
Create a screenshot ingester with custom config.
Sourcepub fn with_tesseract() -> Self
pub fn with_tesseract() -> Self
Create a screenshot ingester backed by the real Tesseract OCR backend.
Sourcepub fn with_tesseract_config(ocr_config: TesseractOcrConfig) -> Self
pub fn with_tesseract_config(ocr_config: TesseractOcrConfig) -> Self
Create a screenshot ingester backed by Tesseract with custom OCR config.
Sourcepub fn with_tesseract_and_config(
ocr_config: TesseractOcrConfig,
config: ScreenshotIngesterConfig,
) -> Self
pub fn with_tesseract_and_config( ocr_config: TesseractOcrConfig, config: ScreenshotIngesterConfig, ) -> Self
Create a screenshot ingester with custom ingestion + Tesseract OCR configs.
Sourcepub fn with_apple_vision() -> Self
pub fn with_apple_vision() -> Self
Create a screenshot ingester backed by Apple’s Vision OCR (macOS-only at runtime).
Sourcepub fn with_apple_vision_config(ocr_config: AppleVisionOcrConfig) -> Self
pub fn with_apple_vision_config(ocr_config: AppleVisionOcrConfig) -> Self
Create a screenshot ingester backed by Apple Vision with custom OCR config.
Sourcepub fn with_apple_vision_and_config(
ocr_config: AppleVisionOcrConfig,
config: ScreenshotIngesterConfig,
) -> Self
pub fn with_apple_vision_and_config( ocr_config: AppleVisionOcrConfig, config: ScreenshotIngesterConfig, ) -> Self
Create a screenshot ingester with custom ingestion + Apple Vision OCR configs.
Sourcepub async fn ingest_file(&self, path: &Path) -> Result<ScreenshotDocument>
pub async fn ingest_file(&self, path: &Path) -> Result<ScreenshotDocument>
Ingest a screenshot image file into structured OCR chunks.
Sourcepub async fn ingest_as_entry(&self, path: &Path) -> Result<KnowledgeEntry>
pub async fn ingest_as_entry(&self, path: &Path) -> Result<KnowledgeEntry>
Ingest a screenshot and convert directly to a knowledge entry scaffold.