pub struct ReplayBuffer<T> { /* private fields */ }Expand description
Experience replay buffer using reservoir sampling.
This ensures uniform coverage of past experiences for stable learning, preventing catastrophic forgetting as described in the ruvector-gnn crate.
Implementations
Sourceimpl<T: Clone> ReplayBuffer<T>
impl<T: Clone> ReplayBuffer<T>
Sourcepub fn total_seen(&self) -> u64
pub fn total_seen(&self) -> u64
Get total experiences seen.