pub struct FewShotLearner { /* private fields */ }Expand description
Few-shot learner for quick adaptation.
Given a small number of examples, adapts quickly using meta-learned priors.
Implementations
Sourceimpl FewShotLearner
impl FewShotLearner
Sourcepub fn from_meta(meta: &MetaLearner, task_embedding: Option<&[f32]>) -> Self
pub fn from_meta(meta: &MetaLearner, task_embedding: Option<&[f32]>) -> Self
Create from meta-learner initialization.
Sourcepub fn with_adapt_lr(self, lr: f32) -> Self
pub fn with_adapt_lr(self, lr: f32) -> Self
Set adaptation learning rate.
Sourcepub fn with_adapt_steps(self, steps: usize) -> Self
pub fn with_adapt_steps(self, steps: usize) -> Self
Set number of adaptation steps.
Sourcepub fn add_example(&mut self, features: Vec<f32>, target: f32)
pub fn add_example(&mut self, features: Vec<f32>, target: f32)
Add an example to the support set.
Sourcepub fn adapt(&mut self)
pub fn adapt(&mut self)
Adapt to the support set.
Performs gradient descent on support set to adapt parameters from meta-learned initialization.
Sourcepub fn get_adapted_params(&self) -> &[f32]
pub fn get_adapted_params(&self) -> &[f32]
Get final adapted parameters.
Sourcepub fn support_size(&self) -> usize
pub fn support_size(&self) -> usize
Number of support examples.