PhotoIngester

Struct PhotoIngester 

pub struct PhotoIngester { /* private fields */ }
Photo ingester backed by an OCR backend implementation.

Implementations

Source

impl PhotoIngester

pub fn new(backend: Arc<dyn OcrBackend>) -> Self

Create a new photo ingester with default config.

pub fn with_config( backend: Arc<dyn OcrBackend>, config: PhotoIngesterConfig, ) -> Self

Create a photo ingester with custom config.

pub fn with_tesseract() -> Self

Create a photo ingester backed by the real Tesseract OCR backend.

pub fn with_tesseract_config(ocr_config: TesseractOcrConfig) -> Self

Create a photo ingester backed by Tesseract with custom OCR config.

pub fn with_tesseract_and_config( ocr_config: TesseractOcrConfig, config: PhotoIngesterConfig, ) -> Self

Create a photo ingester with custom ingestion + Tesseract OCR configs.

pub fn with_apple_vision() -> Self

Create a photo ingester backed by Apple’s Vision OCR (macOS-only at runtime).

pub fn with_apple_vision_config(ocr_config: AppleVisionOcrConfig) -> Self

Create a photo ingester backed by Apple Vision with custom OCR config.

pub fn with_apple_vision_and_config( ocr_config: AppleVisionOcrConfig, config: PhotoIngesterConfig, ) -> Self

Create a photo ingester with custom ingestion + Apple Vision OCR configs.

pub async fn ingest_file(&self, path: &Path) -> Result<PhotoDocument>

Ingest a photo image file into structured OCR chunks.

pub async fn ingest_as_entry(&self, path: &Path) -> Result<KnowledgeEntry>

Ingest a photo and convert directly to a knowledge entry scaffold.